==> solcore-5.7.1.tar.gz: solcore-5.7.1/README.md <==
[![image](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/qpv-research-group/solcore5/master?urlpath=lab)
[![image](https://zenodo.org/badge/DOI/10.5281/zenodo.1185316.svg)](https://doi.org/10.5281/zenodo.1185316)
[![image](https://img.shields.io/badge/License-LGPLv3-blue.svg)](http://www.gnu.org/licenses/lgpl.html)
[![Documentation Status](http://readthedocs.org/projects/solcore5/badge/?version=latest)](http://solcore5.readthedocs.io/en/latest/?badge=latest)
![Solcore](https://github.com/qpv-research-group/solcore5/workflows/Solcore/badge.svg)
[![codecov](https://codecov.io/gh/qpv-research-group/solcore5/branch/devel/graph/badge.svg)](https://codecov.io/gh/qpv-research-group/solcore5)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/a1d2e6f702e64d878a67dcf85ce9b3b7)](https://app.codacy.com/gh/qpv-research-group/solcore5?utm_source=github.com&utm_medium=referral&utm_content=qpv-research-group/solcore5&utm_campaign=Badge_Grade_Settings)


Solcore
=======

**Solcore** was born as a modular set of tools, written (almost) entirely in Python 3, to address some of the task we had to solve more. With time, however, it has evolved as a complete semiconductor solver able of modelling the optical and electrical properties of a wide range of solar cells, from quantum well devices to multi-junction solar cells.

Please, visit [Solcore\'s Documentation](http://docs.solcore.solar), the [Tutorial](docs/source/Examples/tutorial.rst) for a step-by-step example of how to use *Solcore* to model a solar cell and also check the [Examples folder](examples) for more specific information and examples of usage.

![](docs/source/Infographics.jpg)

Contributors
------------

Solcore is the result of many years of developement by many people, trying to put together in a consistent way the tools that the [Quantum Photovoltaics Group at Imperial College London](https://www.imperial.ac.uk/quantum-photovoltaics/) needs for its research in solar cells and photovoltaics. The list of original contributors (hopefully I am not forgetting anyone!) is below, but check the [contributors list](https://github.com/dalonsoa/solcore5/graphs/contributors) for those currently active:

-   Diego Alonso-Álvarez
-   Thomas Wilson
-   Phoebe Pearce
-   Markus Führer
-   Daniel Farrell
-   Tomos Thomas
-   Alvin Chan
-   Ned Ekins-Daukes

==> solcore-5.7.2.tar.gz: solcore-5.7.2/README.md <==
[![image](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/qpv-research-group/solcore5/develop?urlpath=lab)
[![image](https://zenodo.org/badge/DOI/10.5281/zenodo.1185316.svg)](https://doi.org/10.5281/zenodo.1185316)
[![image](https://img.shields.io/badge/License-LGPLv3-blue.svg)](http://www.gnu.org/licenses/lgpl.html)
[![Documentation Status](http://readthedocs.org/projects/solcore5/badge/?version=latest)](http://solcore5.readthedocs.io/en/latest/?badge=latest)
![Solcore](https://github.com/qpv-research-group/solcore5/workflows/Solcore/badge.svg)
[![codecov](https://codecov.io/gh/qpv-research-group/solcore5/branch/develop/graph/badge.svg)](https://codecov.io/gh/qpv-research-group/solcore5)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/a1d2e6f702e64d878a67dcf85ce9b3b7)](https://app.codacy.com/gh/qpv-research-group/solcore5?utm_source=github.com&utm_medium=referral&utm_content=qpv-research-group/solcore5&utm_campaign=Badge_Grade_Settings)


Solcore
=======

**Solcore** was born as a modular set of tools, written (almost) entirely in Python 3, to address some of the task we had to solve more. With time, however, it has evolved as a complete semiconductor solver able of modelling the optical and electrical properties of a wide range of solar cells, from quantum well devices to multi-junction solar cells.

Please, visit [Solcore\'s Documentation](http://docs.solcore.solar), the [Tutorial](docs/source/Examples/tutorial.rst) for a step-by-step example of how to use *Solcore* to model a solar cell and also check the [Examples folder](examples) for more specific information and examples of usage.

![](docs/source/Infographics.jpg)

Contributors
------------

Solcore is the result of many years of developement by many people, trying to put together in a consistent way the tools that the [Quantum Photovoltaics Group at Imperial College London](https://www.imperial.ac.uk/quantum-photovoltaics/) needs for its research in solar cells and photovoltaics. The list of original contributors (hopefully I am not forgetting anyone!) is below, but check the [contributors list](https://github.com/dalonsoa/solcore5/graphs/contributors) for those currently active:

-   Diego Alonso-Álvarez
-   Thomas Wilson
-   Phoebe Pearce
-   Markus Führer
-   Daniel Farrell
-   Tomos Thomas
-   Alvin Chan
-   Ned Ekins-Daukes
